#!/bin/bash

# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#set -x
#--------------------------------------------------------------
#
# Description:
#   Serviceability: Allows the customer to create an inventory
# of the workflow component that were changed since a particular
# installation.
#
# Assumtions:
#    - The user has sufficient privileges to run ExportXML script/batch
#    - TC_HOME env variable is set
#    - exportxml utility (.sh or .cmd depending on the OS) exists in 
#	$TC_HOME/tools
#    - jar utility is in the classpath
#
# Note:
#     It uses the following global variables
#	TC_HOME
# Usage:
#     wfbackup.sh <output_file>
#
# Change Log:
#     December 03, 2003 - <Razvan, Nicolau>: initial file
#
# Input:
#
# Output:
#
#
# Exit Code:
#    Error message printed on stdout
#    Returns $LINENO as the error code or 0 for success
#
# Call Scripts:
#
# Detailed Instructions:
#     <More detailed description of the script functionality>
#
#--------------------------------------------------------------
#

#### Preconditions #####
if [ -z $TC_HOME ] 
then
	printf "\n!! **** TC_HOME is undefined\n\n"
exit 1
fi

if [ -z $JAVA_HOME ]
then
	printf "\n!! **** JAVA_HOME is undefined. Java has to be installed on your system and\nJAVA_HOME set\n\n"
	exit 1
fi

case `uname`
in
  CYGWIN*)
     OSTYPE=CYGWIN
  ;;
  *)
  OSTYPE=UNIX
  ;;
esac

if [ $OSTYPE = "CYGWIN" ] 
then 
	export PATH=$PATH:`cygpath -u $JAVA_HOME`/bin
else
	export PATH=$PATH:$JAVA_HOME/bin
fi

#echo $PATH

which jar > /dev/null
if [ $? != 0 ] 
then
	printf "\n!! **** jar is not in the classpath \n\n"
	exit 1
fi

####################
# Variables
####################

EXPORT_DIR=./backup
UNZIP_DIR=./unzip
REPORTS_DIR=./reports

GLOBAL_LOG_FILE=$REPORTS_DIR/output.log


#############################
# FUNCTIONS

fnc_diff() {
	diff -bw $UNZIP_DIR/$1 $EXPORT_DIR/$1 > $REPORTS_DIR/$1.diff
}

fnc_report() {
	LOG_FILE=$REPORTS_DIR/$1.log
	DIFF_FILE=$REPORTS_DIR/$1.diff

	fnc_diff $1
	echo "" > $LOG_FILE
	printf "\n\n#####################\n$2\n" | tee -a $LOG_FILE $GLOBAL_LOG_FILE
	printf "\n@CREATED\n" | tee -a $LOG_FILE $GLOBAL_LOG_FILE
	cat $DIFF_FILE | grep "Only.*$1" | cut -d: -s -f2 | tee -a $LOG_FILE $GLOBAL_LOG_FILE
	printf "\n@UPDATED\n" | tee -a $LOG_FILE $GLOBAL_LOG_FILE
	cat $DIFF_FILE | grep "^diff" | cut -d/ -s -f7 | tee -a $LOG_FILE $GLOBAL_LOG_FILE
	printf "\n@REMOVED\n" | tee -a $LOG_FILE $GLOBAL_LOG_FILE
	cat $DIFF_FILE | grep "Only.*zip" | cut -d: -s -f2 | tee -a $LOG_FILE $GLOBAL_LOG_FILe
}

fnc_replace() {
	for i in $EXPORT_DIR/$1/*.xml.sed
	do
       	   mv "$i" `echo $i | sed 's/ /_/g' | sed 's/\.sed//g'`
	done
}
#############################
if [ -d $UNZIP_DIR ]
then
	rm -rf $UNZIP_DIR 
fi

mkdir $UNZIP_DIR


if [ -d $EXPORT_DIR ] 
then
	rm -rf $EXPORT_DIR 
fi

mkdir $EXPORT_DIR

if [ ! -d $REPORTS_DIR ]
then
	mkdir $REPORTS_DIR
fi
 
cd  $UNZIP_DIR
jar -xf ../export_1.1.jar 
cd ..
 

if [ $OSTYPE = "CYGWIN" ] 
then
	cmd /C %TC_HOME%\\tools\\exportxml -all -destination=$EXPORT_DIR 
else
	$TC_HOME/tools/exportxml.sh -all -destination=$EXPORT_DIR
fi

cd $EXPORT_DIR/command
if [ $? = 0 ]
then
	for i in ./*.xml; do sed 's/^M//g' "$i" > "$i.sed"; rm "$i" ; done
	cd ../../
fi

cd $EXPORT_DIR/requesttype
if [ $? = 0 ]
then
	for i in ./*.xml; do sed 's/^M//g' "$i" > "$i.sed"; rm "$i" ; done
	cd ../../
fi

cd $EXPORT_DIR/workflow

if [ $? = 0 ]
then
	for i in ./*.xml; do sed 's/^M//g' "$i" > "$i.sed"; rm "$i" ; done
	cd ../../
fi

echo "" > $GLOBAL_LOG_FILE

fnc_report workflow WORKFLOWS
fnc_report command COMMANDS
fnc_report requesttype "REQUEST TYPES"

rm -rf $UNZIP_DIR
#rm -rf $EXPORT_DIR
# rename the files back to XML


fnc_replace command
fnc_replace workflow
fnc_replace requesttype


printf "\n\n!----- The reports are saved in $REPORTS_DIR\n"
printf "\n\n*.diff files contain the specific differences between the original version and your version\n"
printf "\n\n*.log  are the log files for workflows/commands/requesttypes\n"
printf "\n\n$GLOBAL_LOG_FILE contains the whole output\n"
